NonZeroRect

Struct NonZeroRect 

pub struct NonZeroRect { /* private fields */ }
A rectangle defined by left, top, right and bottom edges.

Similar to Rect, but width and height guarantee to be non-zero and positive.

Guarantees

  • All values are finite.
  • Left edge is < right.
  • Top edge is < bottom.
  • Width and height are <= f32::MAX.
  • Width and height are > 0.0

Implementations

Source

impl NonZeroRect

pub fn from_ltrb(left: f32, top: f32, right: f32, bottom: f32) -> Option<Self>

Creates new NonZeroRect.

pub fn from_xywh(x: f32, y: f32, w: f32, h: f32) -> Option<Self>

Creates new NonZeroRect.

pub fn left(&self) -> f32

Returns the left edge.

pub fn top(&self) -> f32

Returns the top edge.

pub fn right(&self) -> f32

Returns the right edge.

pub fn bottom(&self) -> f32

Returns the bottom edge.

pub fn x(&self) -> f32

Returns rect’s X position.

pub fn y(&self) -> f32

Returns rect’s Y position.

pub fn width(&self) -> f32

Returns rect’s width.

pub fn height(&self) -> f32

Returns rect’s height.

pub fn size(&self) -> Size

Returns rect’s size.

pub fn translate_to(&self, x: f32, y: f32) -> Option<Self>

Translates the rect to the specified position.

pub fn transform(&self, ts: Transform) -> Option<Self>

Transforms the rect using the provided Transform.

If the transform is a skew, the result will be a bounding box around the skewed rectangle.

pub fn bbox_transform(&self, bbox: NonZeroRect) -> Self

Applies a bounding box transform.

pub fn to_rect(&self) -> Rect

Converts into Rect.

pub fn to_int_rect(&self) -> IntRect

Converts into IntRect.